==> apache-cxf-3.5.10-src.zip: apache-cxf-3.5.10-src/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/jose/jwejws/MultipartModificationFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jaxrs.security.jose.jwejws;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.List;

import javax.annotation.Priority;
import javax.ws.rs.container.ContainerRequestContext;
import javax.ws.rs.container.ContainerRequestFilter;
import javax.ws.rs.container.PreMatching;

import org.apache.cxf.jaxrs.ext.multipart.Attachment;
import org.apache.cxf.jaxrs.ext.multipart.MultipartInputFilter;
import org.apache.cxf.jaxrs.utils.multipart.AttachmentUtils;
import org.apache.cxf.rs.security.jose.jaxrs.Priorities;

@PreMatching
@Priority(Priorities.JWS_SERVER_READ_PRIORITY - 1)
public class MultipartModificationFilter 
    implements ContainerRequestFilter, MultipartInputFilter {
    
    @Override
    public void filter(ContainerRequestContext ctx) throws IOException {
        AttachmentUtils.addMultipartInFilter(this); 
    }

    @Override
    public void filter(List<Attachment> atts) {
        Attachment dataPart = atts.remove(0);
        Attachment newDataPart = new Attachment(new ByteArrayInputStream("Hi".getBytes()), 
                                                dataPart.getHeaders());
        atts.add(0, newDataPart);
    }
}

==> apache-cxf-4.1.2-src.zip: apache-cxf-4.1.2-src/systests/rs-security/src/test/java/org/apache/cxf/systest/jaxrs/security/jose/jwejws/MultipartModificationFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jaxrs.security.jose.jwejws;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.List;

import jakarta.annotation.Priority;
import jakarta.ws.rs.container.ContainerRequestContext;
import jakarta.ws.rs.container.ContainerRequestFilter;
import jakarta.ws.rs.container.PreMatching;
import org.apache.cxf.jaxrs.ext.multipart.Attachment;
import org.apache.cxf.jaxrs.ext.multipart.MultipartInputFilter;
import org.apache.cxf.jaxrs.utils.multipart.AttachmentUtils;
import org.apache.cxf.rs.security.jose.jaxrs.Priorities;

@PreMatching
@Priority(Priorities.JWS_SERVER_READ_PRIORITY - 1)
public class MultipartModificationFilter 
    implements ContainerRequestFilter, MultipartInputFilter {
    
    @Override
    public void filter(ContainerRequestContext ctx) throws IOException {
        AttachmentUtils.addMultipartInFilter(this); 
    }

    @Override
    public void filter(List<Attachment> atts) {
        Attachment dataPart = atts.remove(0);
        Attachment newDataPart = new Attachment(new ByteArrayInputStream("Hi".getBytes()), 
                                                dataPart.getHeaders());
        atts.add(0, newDataPart);
    }
}
